<?php

// NOTE: THE CODE TO COPY/PASTE STARTS *BELOW* THIS LINE

// Setting a custom timeout value for cURL. Using a high value for priority to ensure the function runs after any other added to the same action hook.
add_action('http_api_curl', 'kingo_custom_curl_timeout', 9999, 1);
function kingo_custom_curl_timeout( $handle ){
	curl_setopt( $handle, CURLOPT_CONNECTTIMEOUT, 30 ); // 30 seconds. Too much for production, only for testing.
	curl_setopt( $handle, CURLOPT_TIMEOUT, 30 ); // 30 seconds. Too much for production, only for testing.
}

// Setting custom timeout for the HTTP request
add_filter( 'http_request_timeout', 'kingo_custom_http_request_timeout', 9999 );
function kingo_custom_http_request_timeout( $timeout_value ) {
	return 30; // 30 seconds. Too much for production, only for testing.
}

// Setting custom timeout in HTTP request args
add_filter('http_request_args', 'kingo_custom_http_request_args', 9999, 1);
function kingo_custom_http_request_args( $r ){
	$r['timeout'] = 30; // 30 seconds. Too much for production, only for testing.
	return $r;
}

add_filter( 'https_local_ssl_verify', '__return_true' );

/**
 * This function runs when WordPress completes its upgrade process
 * It iterates through each plugin updated to see if ours is included
 * @param $upgrader_object Array
 * @param $options Array
 */
function kingo_upgrade_completed( $upgrader_object, $options ) {
	if( $options['action'] == 'update' && $options['type'] == 'theme') {
		//Get verified purchase code data
		$is_verified_envato_purchase_code = kingo_is_registered();
		
		//Check if registered purchase code valid
		if(!empty($is_verified_envato_purchase_code)) {
			$site_domain = kingo_get_site_domain();
			
			if($site_domain != 'localhost') {
				$url = THEMEGOODS_API.'/check-purchase-domain';
				//var_dump($url);
				$data = array(
					'purchase_code' => $is_verified_envato_purchase_code, 
					'domain' => $site_domain,
				);
				$data = wp_json_encode( $data );
				$args = array( 
					'method'   	=> 'POST',
					'body'		=> $data,
				);
				//print '<pre>'; var_dump($args); print '</pre>';
				
				$response = wp_remote_post( $url, $args );
				$response_body = wp_remote_retrieve_body( $response );
				$response_obj = json_decode($response_body);
				
				$response_json = urlencode($response_body);
				/*print '<pre>'; var_dump($response_body); print '</pre>';
				die;*/
				
				//If purchase already in use with other domain then unregister
				if(!$response_obj->response_code) {
					kingo_unregister_theme();
				}
			}
		}
	}
}
add_action( 'upgrader_process_complete', 'kingo_upgrade_completed', 10, 2 );

//Remove one click demo import plugin from admin menus
function bookingo_plugin_page_setup( $default_settings ) {
	$default_settings['parent_slug'] = 'themes.php';
	$default_settings['page_title']  = esc_html__( 'Demo Import' , 'kingo' );
	$default_settings['menu_title']  = esc_html__( 'Import Demo Content' , 'kingo' );
	$default_settings['capability']  = 'import';
	$default_settings['menu_slug']   = 'tg-one-click-demo-import';

	return $default_settings;
}
add_filter( 'pt-ocdi/plugin_page_setup', 'bookingo_plugin_page_setup' );

function bookingo_menu_page_removing() {
	    remove_submenu_page( 'themes.php', 'tg-one-click-demo-import' );
	}
	add_action( 'admin_menu', 'bookingo_menu_page_removing', 99 );

$is_verified_envato_purchase_code = false;

//Get verified purchase code data
$is_verified_envato_purchase_code = kingo_is_registered();

if($is_verified_envato_purchase_code)
{
	function bookingo_import_files() {
	  return array(
	    array(
	      'import_file_name'             => 'Demo 1',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo1/demo.xml',
	      'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'data/demos/demo1/demo.json',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo1/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo1/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 2',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo2/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo2/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo2/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/lawyer/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 3',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo3/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo3/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo3/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/contractor/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 4',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo4/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo4/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo4/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/healthcare/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 5',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo5/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo5/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo5/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/life-coach/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 6',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo6/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo6/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo6/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/yoga/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 7',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo7/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo7/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo7/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/fitness-trainer/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 8',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo8/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo8/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo8/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/barber/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 9',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo9/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo9/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo9/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/bed-and-breakfast-hotel/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 10',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo10/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo10/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo10/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/restaurant/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 11',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo11/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo11/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo11/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/tourism/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 12',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo12/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo12/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo12/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/limousine/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 13',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo13/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo13/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo13/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/technician/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 14',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo14/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo14/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo14/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/financial-advisor/',
	    ),
	    array(
	      'import_file_name'             => 'Demo 15',
	      'local_import_file'            => trailingslashit( get_template_directory() ) . 'data/demos/demo15/demo.xml',
	      'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'data/demos/demo15/demo.dat',
	      'import_preview_image_url'     => trailingslashit( get_template_directory_uri() ) . 'data/demos/demo15/demo.jpg',
	      'preview_url'                  => 'https://themes.themegoods.com/bookingo/demo/medical/',
	    ),
	  );
	}
	add_filter( 'pt-ocdi/import_files', 'bookingo_import_files' );
	
	function bookingo_confirmation_dialog_options ( $options ) {
		return array_merge( $options, array(
			'width'       => 300,
			'dialogClass' => 'wp-dialog',
			'resizable'   => false,
			'height'      => 'auto',
			'modal'       => true,
		) );
	}
	add_filter( 'pt-ocdi/confirmation_dialog_options', 'bookingo_confirmation_dialog_options', 10, 1 );
	
	function bookingo_after_import( $selected_import ) {
		switch($selected_import['import_file_name'])
		{
			case 'Demo 1':
				// Assign menus to their locations.
				$main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );
				$footer_menu = get_term_by( 'name', 'Footer Menu', 'nav_menu' );
			
				set_theme_mod( 'nav_menu_locations', array(
						'primary-menu' => $main_menu->term_id,
						'side-menu' => $main_menu->term_id,
						'footer-menu' => $footer_menu->term_id,
					)
				);
				
			break;
			
			default:
				wp_delete_nav_menu('Main Menu');
			break;
		}
		
		// Assign front page
		$front_page_id = get_page_by_title( 'Home' );
		
		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		
		//Setup theme custom font
		remove_theme_mod('tg_custom_fonts');
		
		$default_custom_fonts = array(
			0 => array(
				'font_name' => 	'CircularStd',
				'font_url' 	=>	get_template_directory_uri().'/fonts/CircularStd-Book.woff',
				'font_fallback'	=> 'sans-serif',
				'font_weight' => 400,
				'font_style' => 'normal',
			),
			1 => array(
				'font_name' => 	'CircularStd',
				'font_url' 	=>	get_template_directory_uri().'/fonts/CircularStd-Medium.woff',
				'font_fallback'	=> 'sans-serif',
				'font_weight' => 700,
				'font_style' => 'normal',
			),
			2 => array(
				'font_name' => 	'CircularStd',
				'font_url' 	=>	get_template_directory_uri().'/fonts/CircularStd-Bold.woff',
				'font_fallback'	=> 'sans-serif',
				'font_weight' => 900,
				'font_style' => 'normal',
			)
		);
		set_theme_mod( 'tg_custom_fonts', $default_custom_fonts );
		
		//Setup default calendar color scheme
		update_option('booked_light_color', '#e5e7e9');
		update_option('booked_dark_color', '#f1f3f4');
		
		switch($selected_import['import_file_name'])
		{
			case 'Demo 1':
			default:
				update_option('booked_button_color', '#1c58f6');
			break;
			
			case 'Demo 2':
			case 'Demo 8':
			case 'Demo 10':
				update_option('booked_button_color', '#cca876');
			break;
			
			case 'Demo 3':
			case 'Demo 13':
				update_option('booked_button_color', '#ff9f43');
			break;
			
			case 'Demo 4':
				update_option('booked_button_color', '#69bfba');
			break;
			
			case 'Demo 5':
			case 'Demo 12':
				update_option('booked_button_color', '#0067da');
			break;
			
			case 'Demo 6':
				update_option('booked_button_color', '#fea2a7');
			break;
			
			case 'Demo 7':
				update_option('booked_button_color', '#ed0909');
			break;
			
			case 'Demo 9':
				update_option('booked_button_color', '#222222');
			break;
			
			case 'Demo 11':
				update_option('booked_button_color', '#262171');
			break;
			
			case 'Demo 14':
				update_option('booked_button_color', '#00172d');
			break;
			
			case 'Demo 15':
				update_option('booked_button_color', '#3498db');
			break;
		}
		
		switch($selected_import['import_file_name'])
		{
			case 'Demo 1':
				// Assign Woocommerce related page
				$shop_page_id = get_page_by_title( 'Shop' );
				update_option( 'woocommerce_shop_page_id', $shop_page_id->ID );
				
				$cart_page_id = get_page_by_title( 'Cart' );
				update_option( 'woocommerce_cart_page_id', $cart_page_id->ID );
				
				$checkout_page_id = get_page_by_title( 'Checkout' );
				update_option( 'woocommerce_checkout_page_id', $checkout_page_id->ID );
				
				$myaccount_page_id = get_page_by_title( 'My account' );
				update_option( 'woocommerce_myaccount_page_id', $myaccount_page_id->ID );
			break;
		}
		
		// 'Hello World!' post
	    wp_delete_post( 4, true );
	
	    // 'Sample page' page
	    wp_delete_post( 5, true );
	    
	    //Set permalink
	    global $wp_rewrite;
		$wp_rewrite->set_permalink_structure('/%postname%/');
	}
	add_action( 'pt-ocdi/after_import', 'bookingo_after_import' );
	add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
}

//Disable Elementor getting started
add_action( 'admin_init', function() {
	if ( did_action( 'elementor/loaded' ) ) {
		remove_action( 'admin_init', [ \Elementor\Plugin::$instance->admin, 'maybe_redirect_to_getting_started' ] );
	}
}, 1 );

add_filter( 'zm_alr_login_redirect_url', 'bookingo_zm_alr_login_redirect_url', 16, 3 );
function bookingo_zm_alr_login_redirect_url() {
	if ( validate_username(sanitize_user($_POST['zm_alr_login_user_name'])) ){
		if ( username_exists(sanitize_user($_POST['zm_alr_login_user_name'])) ){
			$user = get_user_by( 'login', sanitize_user($_POST['zm_alr_login_user_name']) );
			
			if ( wp_check_password( $_POST['zm_alr_login_password'], $user->data->user_pass, $user->ID ) )
			{
				$user_homepage = get_the_author_meta( 'user_homepage', $user->ID );
				$user_loggedin_url = get_permalink($user_homepage);
				
			    return $user_loggedin_url;
			}
		}
	}
}
	
add_filter( 'the_password_form', 'bookingo_password_form' );
function bookingo_password_form() {
    $post = bookingo_get_wp_post();
    
    $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
    
    $return_html = '<div class="protected-post-header"><h1>' . esc_html($post->post_title) . '</h1></div>';
    $return_html.= '<form class="protected-post-form" action="' .wp_login_url(). '?action=postpass" method="post">';
    $return_html.= '<div class="protected-post-text">'.esc_html__( "This content is password protected. To view it please enter your password below:", 'kingo'  ).'</div><input name="post_password" id="' . $label . '" type="password" size="40" />';
    
    $return_html.= '<input type="submit" name="Submit" class="button" value="' . esc_html__( "Authenticate", 'kingo' ) . '" />';
    $return_html.= '</form>';
    
    return $return_html;
}
	
if ( ! function_exists( 'bookingo_theme_kirki_update_url' ) ) {
    function bookingo_theme_kirki_update_url( $config ) {
        $config['url_path'] = get_template_directory_uri() . '/modules/kirki/';
        return $config;
    }
}
add_filter( 'kirki/config', 'bookingo_theme_kirki_update_url' );

add_action( 'customize_register', function( $wp_customize ) {
	/**
	 * The custom control class
	 */
	class Kirki_Controls_Title_Control extends Kirki_Control_Base {
		public $type = 'title';
		public function render_content() { 
			echo esc_html($this->label);
		}
	}
	// Register our custom control with Kirki
	add_filter( 'kirki/control_types', function( $controls ) {
		$controls['title'] = 'Kirki_Controls_Title_Control';
		return $controls;
	} );

} );

//add_action( 'admin_footer', 'bookingo_welcome_dashboard_widget' );
function bookingo_welcome_dashboard_widget() {
 // Bail if not viewing the main dashboard page
 if ( get_current_screen()->base !== 'dashboard' ) {
  return;
 }
 ?>

 <div id="bookingo-welcome-id" class="welcome-panel" style="display: none;">
  <div class="welcome-panel-content">
	  <div style="height:10px"></div>
   <h2>Welcome to <?php echo esc_html(BOOKINGO_THEMENAME); ?> Theme</h2>
   <p class="about-description">Welcome to <?php echo esc_html(BOOKINGO_THEMENAME); ?> theme. <?php echo esc_html(BOOKINGO_THEMENAME); ?> is now installed and ready to use! Read below for additional informations. We hope you enjoy using the theme!</p>
   
   <br style="clear:both;"/>
   
<?php

$is_verified_envato_purchase_code = false;

//Get verified purchase code data
$pp_verified_envato_bookingo = get_option("pp_verified_envato_bookingo");
if(!empty($pp_verified_envato_bookingo))
{
	$is_verified_envato_purchase_code = true;
}

if(!$is_verified_envato_purchase_code)
{
?>
	<div style="height:20px"></div>
	
	<div class="tg_notice">
			<span class="dashicons dashicons-warning" style="color:#FF3B30"></span> 
			Please visit <a href="<?php echo admin_url("themes.php?page=functions.php#pp_panel_registration"); ?>">Product Registration page</a> and enter a valid Envato Token to import the full <?php echo BOOKINGO_THEMENAME; ?>' demos and single pages through Elementor.
	</div>
		
	<div style="height:40px"></div>
<?php
}
?>
   
   <div class="welcome-panel-column-container">
    
    <div class="one_half">
		<div class="step_icon">
			<a href="<?php echo admin_url("themes.php?page=install-required-plugins"); ?>">
				<i class="fas fa-plug"></i>
				<div class="step_title">Install Plugins</div>
			</a>
		</div>
		<div class="step_info">
			<?php echo esc_html(BOOKINGO_THEMENAME); ?> has required and recommended plugins in order to build your website using layouts you saw on our demo site. We recommend you to install all plugins first.
		</div>
	</div>
	
	<div class="one_half last">
		<div class="step_icon">
			<a href="<?php echo admin_url("post-new.php?post_type=page"); ?>">
				<i class="fa fa-file-alt"></i>
				<div class="step_title">Create Page</div>
			</a>
		</div>
		<div class="step_info">
			<?php echo esc_html(BOOKINGO_THEMENAME); ?> support standard WordPress page option. You can also use Elementor page builder to create and organise page contents.
		</div>
	</div>
	
	<div class="one_half">
		<div class="step_icon">
			<a href="<?php echo admin_url("customize.php"); ?>">
				<i class="fas fa-sliders-h"></i>
				<div class="step_title">Customize Theme</div>
			</a>
		</div>
		<div class="step_info">
			Start customize theme's layouts, typography, elements colors using WordPress customize and see your changes in live preview instantly.
		</div>
	</div>
	
	<div class="one_half last">
		<div class="step_icon">
			<a href="<?php echo admin_url("themes.php?page=functions.php#pp_panel_import-demo"); ?>">
				<i class="fas fa-database"></i>
				<div class="step_title">Import Demo</div>
			</a>
		</div>
		<div class="step_info">
			We created various ready to use pages for you to use as starting point of your website. We recommend you to install all recommended plugins before importing ready site contents.
		</div>
	</div>

<?php
$booked_plugin_activated = class_exists('booked_plugin');

//Check if booked plugin is activated
if($booked_plugin_activated)
{
?>
	
	<br style="clear:both;"/>
	<div class="one_half nomargin">
		<div class="step_icon">
			<a href="<?php echo admin_url("admin.php?page=booked-install-addons"); ?>">
				<i class="fas fa-calendar-plus"></i>
				<div class="step_title">Booking Add-ons</div>
			</a>
		</div>
		<div class="step_info">
			Enhance booking features from various addons which are available for free. adding Woocommerce payment support, Calendar feeds and Front-end agents options.
		</div>
	</div>
	
	<div class="one_half last nomargin">
		<div class="step_icon">
			<a href="<?php echo admin_url("admin.php?page=booked-settings"); ?>">
				<i class="fas fa-calendar-alt"></i>
				<div class="step_title">Calendar Settings</div>
			</a>
		</div>
		<div class="step_info">
			You can configure all calendar booking options here including time slots, display options, color settings and many more.
		</div>
	</div>
	
<?php
}
?>
	
	<br style="clear:both;"/>
	
	<h1>Support</h1>
	<div style="height:20px"></div>
	<div class="one_half nomargin">
		<div class="step_icon">
			<a href="https://themegoods.ticksy.com/submit/" target="_blank">
				<i class="fas fa-life-ring"></i>
				<div class="step_title">Submit a Ticket</div>
			</a>
		</div>
		<div class="step_info">
			We offer excellent support through our ticket system. Please make sure you prepare your purchased code first to access our services.
		</div>
	</div>
	
	<div class="one_half last nomargin">
		<div class="step_icon">
			<a href="https://docs.themegoods.com/docs/bookingo" target="_blank">
				<i class="fas fa-book"></i>
				<div class="step_title">Theme Document</div>
			</a>
		</div>
		<div class="step_info">
			This is the place to go find all reference aspects of theme functionalities. Our online documentation is resource for you to start using theme.
		</div>
	</div>
	
	<br style="clear:both;"/>
	
	<div style="height:30px"></div>
    
   </div>
  </div>
 </div>
 <script>
  jQuery(document).ready(function($) {
   	jQuery('#welcome-panel').after($('#bookingo-welcome-id').show());
  });
 </script>

<?php }

function bookingo_tag_cloud_filter($args = array()) {
   $args['smallest'] = 12;
   $args['largest'] = 12;
   $args['unit'] = 'px';
   return $args;
}

add_filter('widget_tag_cloud_args', 'bookingo_tag_cloud_filter', 90);

//Customise Widget Title Code
add_filter( 'dynamic_sidebar_params', 'bookingo_wrap_widget_titles', 1 );
function bookingo_wrap_widget_titles( array $params ) 
{
	$widget =& $params[0];
	$widget['before_title'] = '<h2 class="widgettitle"><span>';
	$widget['after_title'] = '</span></h2>';
	
	return $params;
}

//Control post excerpt length
function bookingo_custom_excerpt_length( $length ) {
	return 40;
}
add_filter( 'excerpt_length', 'bookingo_custom_excerpt_length', 200 );


function bookingo_theme_queue_js(){
  if (is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
      wp_enqueue_script( 'comment-reply' );
  }
}
add_action('get_header', 'bookingo_theme_queue_js');


function bookingo_add_meta_tags() {
    $post = bookingo_get_wp_post();
    
    echo '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />';
    
    //Check if responsive layout is enabled
    echo '<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1" />';
	
	//meta for phone number link on mobile
	echo '<meta name="format-detection" content="telephone=no">';
}
add_action( 'wp_head', 'bookingo_add_meta_tags' , 1 );

add_filter('redirect_canonical','custom_disable_redirect_canonical');
function custom_disable_redirect_canonical($redirect_url) {if (is_paged() && is_singular()) $redirect_url = false; return $redirect_url; }

function bookingo_body_class_names($classes) 
{
	$post = bookingo_get_wp_post();
	
	if(isset($post->ID))
	{
		//Check if boxed layout is enable
		$page_boxed_layout = get_post_meta($post->ID, 'page_boxed_layout', true);
		if(!empty($page_boxed_layout))
		{
			$classes[] = esc_attr('tg_boxed');
		}
		
		//Get Page Menu Transparent Option
		$page_menu_transparent = get_post_meta($post->ID, 'page_menu_transparent', true);
		if(!empty($page_menu_transparent))
		{
			$classes[] = esc_attr('tg_menu_transparent');
		}
	}
	
	//if password protected
	if(post_password_required() && is_page())
	{
	   	$classes[] = esc_attr('tg_password_protected');
	}
	
	//Get lightbox color scheme
	$tg_lightbox_color_scheme = get_theme_mod('tg_lightbox_color_scheme', 'black');
	
	if(!empty($tg_lightbox_color_scheme))
	{
		$classes[] = esc_attr('tg_lightbox_'.$tg_lightbox_color_scheme);
	}
	
	//Get sidemenu on desktop class
	$tg_sidemenu = get_theme_mod('tg_sidemenu', false);

	if(!empty($tg_sidemenu))
	{
		$classes[] = esc_attr('tg_sidemenu_desktop');
	}
	
	//Get main menu layout
	$tg_menu_layout = bookingo_menu_layout();
	if(!empty($tg_menu_layout))
	{
		$classes[] = esc_attr($tg_menu_layout);
	}
	
	//Get fotoer reveal class
	$tg_footer_reveal = get_theme_mod('tg_footer_reveal', false);
	if(!empty($tg_footer_reveal))
	{
		$classes[] = esc_attr('tg_footer_reveal');
	}
	
	if(is_page() && !comments_open($post->ID) && !class_exists("\\Elementor\\Plugin"))
	{
		$classes[] = esc_attr('comment_close');
	}

	return $classes;
}

//Now add test class to the filter
add_filter('body_class','bookingo_body_class_names');

add_filter('upload_mimes', 'bookingo_add_custom_upload_mimes');
function bookingo_add_custom_upload_mimes($existing_mimes) 
{
  	$existing_mimes['woff'] = 'application/x-font-woff';
  	return $existing_mimes;
}

add_action('init','bookingo_shop_sorting_remove');
function bookingo_shop_sorting_remove() {
	$tg_shop_filter_sorting = get_theme_mod('tg_shop_filter_sorting', true);
	
	if(empty($tg_shop_filter_sorting))
	{
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
		remove_action( 'woocommerce_after_shop_loop', 'woocommerce_catalog_ordering', 30 );
		
		remove_action( 'woocommerce_after_shop_loop', 'woocommerce_result_count', 20 );
		remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
	}
}

add_action( 'show_user_profile', 'bookingo_extra_user_fields' );
add_action( 'edit_user_profile', 'bookingo_extra_user_fields' );
function bookingo_extra_user_fields( $user ) 
{ 
	$available_pages = get_pages();
?>
    <h3><?php esc_html_e('Client Options', 'kingo' ); ?></h3>

    <table class="form-table">
        <tr>
            <th><label for="user_homepage"><?php esc_html_e('Client Homepage', 'kingo' ); ?></label></th>
            <td>
                <select id="user_homepage" name="user_homepage">
	            <?php
		            $user_homepage = get_the_author_meta( 'user_homepage', $user->ID ); 
		            
					foreach($available_pages as $available_page) 
					{  
		        ?>
		        	<option value="<?php echo esc_attr($available_page->ID); ?>" <?php if($user_homepage == $available_page->ID) { ?>selected<?php } ?>><?php echo esc_attr($available_page->post_title); ?></option>
		        <?php
			        }
			    ?>
                </select>
                <span class="description"><?php esc_html_e('Select homepage for this user when logged in successfully', 'kingo' ); ?></span>
            </td>
        </tr>
    </table>
<?php }
	
add_action( 'personal_options_update', 'bookingo_save_extra_user_fields' );
add_action( 'edit_user_profile_update', 'bookingo_save_extra_user_fields' );

function bookingo_save_extra_user_fields( $user_id ) 
{
    if ( !current_user_can( 'edit_user', $user_id ) ) { return false; }else{

        if(isset($_POST['user_homepage']) && $_POST['user_homepage'] != ""){
            update_user_meta( $user_id, 'user_homepage', $_POST['user_homepage'] );
        }
    }
}

add_action( 'admin_enqueue_scripts', 'bookingo_admin_pointers_header' );

function bookingo_admin_pointers_header() {
   if ( bookingo_admin_pointers_check() ) {
      add_action( 'admin_print_footer_scripts', 'bookingo_admin_pointers_footer' );

      wp_enqueue_script( 'wp-pointer' );
      wp_enqueue_style( 'wp-pointer' );
   }
}

function bookingo_admin_pointers_check() {
   $admin_pointers = bookingo_admin_pointers();
   foreach ( $admin_pointers as $pointer => $array ) {
      if ( $array['active'] )
         return true;
   }
}

function bookingo_admin_pointers_footer() {
   $admin_pointers = bookingo_admin_pointers();
?>
<script type="text/javascript">
/* <![CDATA[ */
( function($) {
   <?php
   foreach ( $admin_pointers as $pointer => $array ) {
      if ( $array['active'] ) {
         ?>
         $( '<?php echo esc_js($array['anchor_id']); ?>' ).pointer( {
            content: '<?php echo wp_kses_post($array['content']); ?>',
            position: {
            edge: '<?php echo esc_js($array['edge']); ?>',
            align: '<?php echo esc_js($array['align']); ?>'
         },
            close: function() {
               $.post( ajaxurl, {
                  pointer: '<?php echo esc_js($pointer); ?>',
                  action: 'dismiss-wp-pointer'
               } );
            }
         } ).pointer( 'open' );
         <?php
      }
   }
   ?>
} )(jQuery);
/* ]]> */
</script>
   <?php
}

function bookingo_admin_pointers() {
   $dismissed = explode( ',', (string) get_user_meta( get_current_user_id(), 'dismissed_wp_pointers', true ) );
   $prefix = 'bookingo_admin_pointer';
   
   //Page help pointers
   $elementor_builder_content = '<h3>Page Builder</h3>';
   $elementor_builder_content .= '<p>Basically you can use WordPress visual editor to create page content but theme also has another way to create page content. By using Elementor Page Builder, you would be ale to drag&drop each content block without coding knowledge. Click here to enable Elementor.</p>';
   
   $page_options_content = '<h3>Page Options</h3>';
   $page_options_content .= '<p>You can customise various options for this page including menu styling, page templates etc.</p>';
   
   $page_featured_image_content = '<h3>Page Featured Image</h3>';
   $page_featured_image_content .= '<p>Upload or select featured image for this page to displays it as background header.</p>';
   
   //Post help pointers
   $post_options_content = '<h3>Post Options</h3>';
   $post_options_content .= '<p>You can customise various options for this post including its layout and featured content type.</p>';
   
   $post_featured_image_content = '<h3>Post Featured Image (*Required)</h3>';
   $post_featured_image_content .= '<p>Upload or select featured image for this post to displays it as post image on blog, archive, category, tag and search pages.</p>';

   $tg_pointer_arr = array(   
   	  //Page help pointers
      $prefix . '_elementor_builder' => array(
         'content' => $elementor_builder_content,
         'anchor_id' => '#elementor-switch-mode-button .elementor-switch-mode-off',
         'edge' => 'top',
         'align' => 'left',
         'active' => ( ! in_array( $prefix . '_elementor_builder', $dismissed ) )
      ),
      
      $prefix . '_page_options' => array(
         'content' => $page_options_content,
         'anchor_id' => 'body.post-type-page #page_option_page_menu_transparent',
         'edge' => 'top',
         'align' => 'left',
         'active' => ( ! in_array( $prefix . '_page_options', $dismissed ) )
      ),
      
      $prefix . '_page_featured_image' => array(
         'content' => $page_featured_image_content,
         'anchor_id' => 'body.post-type-page #set-post-thumbnail',
         'edge' => 'top',
         'align' => 'left',
         'active' => ( ! in_array( $prefix . '_page_featured_image', $dismissed ) )
      ),
      
      //Post help pointers
      $prefix . '_post_options' => array(
         'content' => $post_options_content,
         'anchor_id' => 'body.post-type-post #post_option_post_layout',
         'edge' => 'top',
         'align' => 'left',
         'active' => ( ! in_array( $prefix . '_post_options', $dismissed ) )
      ),
      
      $prefix . '_post_featured_image' => array(
         'content' => $post_featured_image_content,
         'anchor_id' => 'body.post-type-post #set-post-thumbnail',
         'edge' => 'top',
         'align' => 'left',
         'active' => ( ! in_array( $prefix . '_post_featured_image', $dismissed ) )
      ),
   );

   return $tg_pointer_arr;
}

remove_action( 'wp_head', 'rest_output_link_header', 10);    
remove_action( 'template_redirect', 'rest_output_link_header', 11);
?>